@@ -19,7 +19,7 @@
 
 
 __author__ = "Sandro Gauci <sandro@enablesecurity.com>"
-__version__ = '0.3.2'
+__version__ = '0.3.3'
 
 
 import re
@@ -179,6 +179,7 @@ def dictionaryattack(dictionaryfile):
         if len(r) == 0:
             break
         yield(r.strip())
+    dictionaryfile.flush()
     dictionaryfile.close()
 
 
@@ -328,7 +329,7 @@ def parseHeader(buff, type='response'):
             #if len(_t) == 3:
             #    method, uri, sipversion = _t
         else:
-            log.warn('Could not parse the first header line: %s' % _t.__repr__())
+            log.warn('Could not parse the first header line: %s' % headerlines[0])
             return r
         r['headers'] = dict()
         for headerline in headerlines[1:]:
@@ -428,11 +429,7 @@ def getToTag(buff):
 
 
 def challengeResponse(auth, method, uri):
-    try:
-        from hashlib import md5
-    except ImportError:
-        import md5 as md5sum
-        md5 = md5sum.new
+    from hashlib import md5
     username = auth["username"]
     realm = auth["realm"]
     passwd = auth["password"]
@@ -1150,6 +1147,7 @@ def getAuthHeader(pkt):
     return None
 
 
+
 def check_ipv6(n):
     log = logging.getLogger('check_ipv6')
     if '/' in n:
